
use "${pathdata}\China.dta", clear


*recode educ

replace edattaind=. if edattaind>900|edattaind==0
gen yrschool=0 if edattaind==110
replace yrschool=3 if edattaind==120
replace yrschool=6 if edattaind==212
replace yrschool=9 if edattaind==221
replace yrschool=12 if edattaind==321|edattaind==311
replace yrschool=14 if edattaind==322|edattaind==312
replace yrschool=15 if edattaind==400

*recode fertility
replace chborn=. if chborn>89
replace chsurv=. if chsurv>89		

*create religion shares
replace ethniccn=. if ethniccn==99
tab ethniccn, gen(ethn)					 // generating 57 dummies from ethnicity variable 


save "${pathdata}\China_analysis.dta", replace

drop if age<18|age>55 						// All characteristics of regencies are computed using the adult working population
cap gen infmort=1-chsurv/chborn  			// Computes infant mortality based on the difference between chborn and chsurv
cap replace infmort=1-chsurv_i/chborn_i if infmort==.  			// Computes infant mortality based on the difference between chborn and chsurv

collapse (mean) ethn1 ethn10 ethn11 ethn12 ethn13 ethn14 ethn15 ethn16 ethn17 ethn18 ethn19 ethn2 ethn20 ethn21 ethn22 ethn23 ethn24 ethn25 ethn26 ethn27 ethn28 ethn29 ethn3 ethn30 ethn31 ethn32 ethn33 ethn34 ethn35 ethn36 ethn37 ethn38 ethn39 ethn4 ethn40 ethn41 ethn42 ethn43 ethn44 ethn45 ethn46 ethn47 ethn48 ethn49 ethn5 ethn50 ethn51 ethn52 ethn53 ethn54 ethn55 ethn56 ethn6 ethn7 ethn8 ethn9  yrschool infmort geolev1 [pweight=perwt], by(year geolev2) 

*rename district level variables
foreach var of varlist ethn1 ethn10 ethn11 ethn12 ethn13 ethn14 ethn15 ethn16 ethn17 ethn18 ethn19 ethn2 ethn20 ethn21 ethn22 ethn23 ethn24 ethn25 ethn26 ethn27 ethn28 ethn29 ethn3 ethn30 ethn31 ethn32 ethn33 ethn34 ethn35 ethn36 ethn37 ethn38 ethn39 ethn4 ethn40 ethn41 ethn42 ethn43 ethn44 ethn45 ethn46 ethn47 ethn48 ethn49 ethn5 ethn50 ethn51 ethn52 ethn53 ethn54 ethn55 ethn56 ethn6 ethn7 ethn8 ethn9 yrschool infmort {
rename `var' i`var'
}

save "${pathdata}\China_districts.dta", replace  // Contains shares of each ethnic group, mean years of schooling and infant mortality by census year and districts

clear*
use "${pathdata}\China_analysis.dta", clear
merge m:1 geolev2 year using "$pathdata\China_districts.dta", keepusing(iethn1 iethn10 iethn11 iethn12 iethn13 iethn14 iethn15 iethn16 iethn17 iethn18 iethn19 iethn2 iethn20 iethn21 iethn22 iethn23 iethn24 iethn25 iethn26 iethn27 iethn28 iethn29 iethn3 iethn30 iethn31 iethn32 iethn33 iethn34 iethn35 iethn36 iethn37 iethn38 iethn39 iethn4 iethn40 iethn41 iethn42 iethn43 iethn44 iethn45 iethn46 iethn47 iethn48 iethn49 iethn5 iethn50 iethn51 iethn52 iethn53 iethn54 iethn55 iethn56 iethn6 iethn7 iethn8 iethn9 iyrschool iinfmort)

drop _m

*assign local share of own religious group to each observation 
cap drop ethn_sh

gen ethn_sh=.
forvalues i=1/56 {
    replace ethn_sh=iethn`i' if ethniccn==`i'
}

*create samples for regression analysis 
cap drop f_selec e_selec*
gen f_selec=1 if age>39&age<66&sex==2&yrschool!=.&iinfmort!=.&ethn_sh!=.&edattaind!=.
gen e_selec=3 if age>25&age<33&yrschool!=.&ethn_sh!=.&edattaind!=.

replace birthyr=year-age if birthyr==.
gen marr=(marst==2)
gen mig=(156000+bplcn!=geolev1&bplcn!=.)

save "${pathdata}\China_analysis.dta", replace

 
 *Create indicators for the distribution of group size for fertility sample (otherwise running xtile takes a very long time)
cap drop ethn_sh_*
keep if f_selec==1
xtile ethn_sh_dec_f= ethn_sh if f_selec==1, nq(10) // create a categorical variable for the deciles of ethn_sh for fertility sample
xtile ethn_sh_dec_20_f= ethn_sh if f_selec==1, nq(20) // create a categorical variable for the deciles of ethn_sh for fertility sample

* gen categories based on deciles, with first decile divided in 2 vintiles
gen ethn_sh_dec_11_f=ethn_sh_dec_20_f-1 if ethn_sh_dec_20_f<3
replace ethn_sh_dec_11_f=ethn_sh_dec_f if ethn_sh_dec_f>1

cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values ethn_sh_dec_11_f ethn_sh_dec_11_f eleveniles


save "${pathdata}\China_fertility.dta", replace

 *Create indicators for the distribution of group size for education sample (otherwise running xtile takes a very long time)

 use "${pathdata}\China_analysis.dta", clear

keep if e_selec==3

xtile ethn_sh_dec_e3= ethn_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of ethn_sh for education sample
xtile ethn_sh_dec_20_e3= ethn_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of ethn_sh for education sample
gen ethn_sh_dec_11_e3=ethn_sh_dec_20_e3-1 if ethn_sh_dec_20_e3<3
replace ethn_sh_dec_11_e3=ethn_sh_dec_e3 if ethn_sh_dec_e3>1 


cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values ethn_sh_dec_11_e* ethn_sh_dec_11_e* eleveniles


save "${pathdata}\China_education.dta", replace
