
use "${pathdata}\Ghana.dta"


*recode educ
replace yrschool=. if yrschool>89
replace edattaind=. if edattaind==0

*recode fertility
replace chborn=. if chborn>89
replace chsurv=. if chsurv>89

*create religion shares
tab religion, gen(rel)					 // generating 4 dummies from religion variable 
gen tool=floor(religiond/1000 ) if religiond>7000|religiond<6000
replace tool=religiond if tool==.
tab tool, gen(reld)				 // generating 7 dummies form religiond variable
drop tool

save "${pathdata}/Ghana_analysis.dta", replace

drop if age<18|age>55 					// All characteristics of regencies are computed using the adult working population
cap gen infmort=1-chsurv/chborn  			// Computes infant mortality based on the difference between chborn and chsurv

collapse (mean) rel1 rel2 rel3 rel4 reld1-reld7 yrschool infmort geolev1 [pweight=perwt], by(year geolev2) 

*rename district level variables
foreach var of varlist rel1-rel4 reld1-reld7 yrschool infmort {
rename `var' i`var'
}

save "${pathdata}\Ghana_districts.dta", replace

	
clear*
use "${pathdata}\Ghana_analysis.dta"
merge m:1 geolev2 year using "$pathdata\Ghana_districts.dta", keepusing(irel1-irel4 ireld1-ireld7 iyrschool iinfmort)
drop _m

*assign local share of own religious group to each observation 
cap drop rel_sh rel_shd
gen rel_sh=irel1 if religion==1
replace rel_sh=irel2 if religion==5
replace rel_sh=irel3 if religion==6
replace rel_sh=irel4 if religion==7
*same with detailed religion
gen rel_shd=ireld1 if religion==1
replace rel_shd=ireld2 if religion==5
replace rel_shd=ireld3 if religion==7
replace rel_shd=ireld4 if religiond==6001
replace rel_shd=ireld5 if religiond==6003
replace rel_shd=ireld6 if religiond==6005
replace rel_shd=ireld7 if religiond==6163

*create samples for regression analysis 
cap drop f_selec e_selec*
gen f_selec=1 if age>39&age<66&sex==2&yrschool!=.&iinfmort!=.&rel_sh!=.&edattaind!=.
gen e_selec=3 if age>25&age<33&yrschool!=.&rel_sh!=.&edattaind!=.

gen birthyr=year-age
gen marr=(marst==2)
gen mig=(288000+bplgh!=geolev1)

*Create indicators for the distribution of group size
cap drop rel_sh_*
xtile rel_sh_dec_f= rel_sh if f_selec==1, nq(10) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_e3= rel_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of rel_sh for education sample

xtile rel_sh_dec_20= rel_sh, nq(20) // create a categorical variable for the deciles of rel_sh
xtile rel_sh_dec_20_f= rel_sh if f_selec==1, nq(20) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_20_e3= rel_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of rel_sh for education sample

* gen categories based on deciles, with first decile divided in 2 vintiles
gen rel_sh_dec_11_f=rel_sh_dec_20_f-1 if rel_sh_dec_20_f<3
replace rel_sh_dec_11_f=rel_sh_dec_f if rel_sh_dec_f>1
gen rel_sh_dec_11_e=rel_sh_dec_20_e-1 if rel_sh_dec_20_e<3
replace rel_sh_dec_11_e3=rel_sh_dec_e if rel_sh_dec_e>1 


cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values rel_sh_dec_11_f rel_shd_dec_11_f eleveniles
label values rel_sh_dec_11_e* rel_shd_dec_11_e* eleveniles

save "${pathdata}\final_dataset\Ghana_analysis.dta", replace


