
use "${pathdata}\Indonesia.dta"

*recode religion
replace religiond=6003 if religiond>6140&religiond<6151 // recodes together protestants and other christians
replace religiond=7134 if religiond==7135|religiond==7900 // recodes together confucianism and other Indonesia
replace religiond=0 if religiond>7900&religiond!=. // recodes together not in the universe (only 2010) and other

*recode educ
replace yrschool=. if yrschool>89
replace yrschool=0 if edattaind==100 & yrschool==.
replace yrschool=0 if edattaind==110 & yrschool==.
replace yrschool=3 if edattaind==120 & yrschool==.
replace yrschool=6 if edattaind==212 & yrschool==.
replace yrschool=9 if edattaind==221 & yrschool==.
replace yrschool=9 if edattaind==222 & yrschool==.
replace yrschool=12 if edattaind==311 & yrschool==.
replace yrschool=12 if edattaind==321 & yrschool==.
replace yrschool=15 if edattaind==312 & yrschool==.
replace yrschool=15 if edattaind==322 & yrschool==.
replace yrschool=16 if edattaind==400 & yrschool==.

replace edattaind=. if edattaind==0|edattaind==999

*recode fertility
replace chborn=. if chborn>89
replace chsurv=. if chsurv>89

*create religion shares
tab religiond, gen(rel) // generating dummies from religion variable


save "${pathdata}\Indonesia_analysis.dta", replace

*************************************************************************
*Prepare data for robustness check with ethnic group rather than religion
*************************************************************************
preserve

*create aggregate ethnic groups based on https://www.iseas.edu.sg/images/pdf/iseas_working_papers_2014_1.pdf
do "${path}\1b_ethnic_indo.do"

drop if ethnicid==.|ethnicid==9999

*create ethnic group shares
tab ethnicid_agg, gen(ethnic) // generating dummies from religion variable

drop if age<18|age>55 // All characteristics of regencies are computed using the adult working population

collapse (mean) ethnic1 ethnic2 ethnic3 ethnic4 ethnic5 ethnic6 ethnic7 ethnic8 ethnic9 ethnic10 ethnic11 ethnic12 ethnic13 ethnic14 ethnic15 ethnic16 ethnic17 ethnic18 ethnic19 ethnic20 ethnic21 ethnic22 ethnic23 ethnic24 ethnic25 ethnic26 ethnic27 ethnic28 ethnic29 ethnic30 ethnic31 ethnic32 ethnic33 ethnic34 ethnic35 ethnic36 ethnic37 ethnic38 ethnic39 ethnic40 ethnic41 ethnic42 ethnic43 ethnic44 ethnic45 ethnic46 ethnic47 ethnic48 ethnic49 ethnic50 ethnic51 ethnic52 ethnic53 ethnic54 ethnic55 ethnic56 ethnic57 ethnic58 ethnic59 ethnic60 ethnic61 ethnic62 ethnic63 ethnic64 ethnic65 ethnic66 ethnic67 ethnic68 ethnic69 ethnic70 ethnic71 ethnic72 ethnic73 ethnic74 ethnic75 ethnic76 ethnic77 ethnic78 ethnic79 ethnic80 ethnic81 ethnic82 ethnic83 ethnic84 ethnic85 ethnic86 ethnic87 ethnic88 ethnic89 ethnic90 ethnic91 ethnic92 ethnic93 ethnic94 ethnic95 ethnic96 ethnic97 ethnic98 ethnic99 ethnic100 ethnic101 ethnic102 ethnic103 ethnic104 ethnic105 ethnic106 ethnic107 ethnic108 ethnic109 ethnic110 ethnic111 ethnic112 ethnic113 ethnic114 ethnic115 ethnic116 ethnic117 gelolev1 [fweight=perwt], by(year geolev2) 

save "${pathdata}\regencies_ethnic.dta", replace  // Contains shares of each ethnic group by regency - groups 19 and 60 have 0 observations
restore 

*************************************************************************
*Prepare general regency-level data
*************************************************************************

drop if age<18|age>55 // All characteristics of regencies are computed using the adult working population
gen infmort=1-chsurv/chborn  // Computes infant mortality based on the difference between chborn and chsurv

collapse (mean) rel1 rel2 rel3 rel4 rel5 rel6 rel7 yrschool infmort geolev1 [fweight=perwt], by(year geolev2) 

foreach var of varlist rel1-rel7 yrschool infmort {
	rename `var' i`var'
}		

save "${pathdata}\regencies_religion.dta", replace

		
clear*
use "${pathdata}\Indonesia_analysis.dta"

gen f_selec=1 if age>44&age<60&sex==2
gen e_selec=3 if age>25&age<33
keep if f_selec==1|e_selec==3

merge m:1 geolev2 year using "${pathdata}\regencies_religion.dta", keepusing(irel1-irel7 iyrschool iinfmort)
drop _m

gen rel_sh=irel1 if religiond==0
replace rel_sh=irel2 if religiond==2000
replace rel_sh=irel3 if religiond==3000
replace rel_sh=irel4 if religiond==5000
replace rel_sh=irel5 if religiond==6001
replace rel_sh=irel6 if religiond==6003
replace rel_sh=irel7 if religiond==7134

replace f_selec=. if iyrschool==.|iinfmort==.|rel_sh==.|chborn==.|edattaind==.|religiond==0
replace e_selec=. if iyrschool==.|rel_sh==.|edattaind==.|religiond==0

replace chsurv=0 if chborn==0
replace f_selec=. if chsurv==.&f_selec==1

gen birthyr=year-age
gen marr=(marst==2)
gen mig=(bplid==geolev1-360000)

xtile rel_sh_dec_f= rel_sh if f_selec==1, nq(10) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_e3= rel_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of rel_sh for education sample

xtile rel_sh_dec_20_f= rel_sh if f_selec==1, nq(20) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_20_e3= rel_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of rel_sh for education sample

* gen categories based on deciles, with first decile divided in 2 vintiles
gen rel_sh_dec_11_f=rel_sh_dec_20_f-1 if rel_sh_dec_20_f<3
replace rel_sh_dec_11_f=rel_sh_dec_f if rel_sh_dec_f>1
gen rel_sh_dec_11_e3=rel_sh_dec_20_e3-1 if rel_sh_dec_20_e3<3
replace rel_sh_dec_11_e3=rel_sh_dec_e3 if rel_sh_dec_e3>1 


label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values rel_sh_dec_11_f eleveniles
label values rel_sh_dec_11_e* eleveniles

save "${pathdata}\Indonesia_analysis.dta", replace


keep if year==2010

merge m:1 geo2_id year using "${pathdata}\regencies_ethnic.dta", keepusing(ethnic1 ethnic2 ethnic3 ethnic4 ethnic5 ethnic6 ethnic7 ethnic8 ethnic9 ethnic10 ethnic11 ethnic12 ethnic13 ethnic14 ethnic15 ethnic16 ethnic17 ethnic18 ethnic19 ethnic20 ethnic21 ethnic22 ethnic23 ethnic24 ethnic25 ethnic26 ethnic27 ethnic28 ethnic29 ethnic30 ethnic31 ethnic32 ethnic33 ethnic34 ethnic35 ethnic36 ethnic37 ethnic38 ethnic39 ethnic40 ethnic41 ethnic42 ethnic43 ethnic44 ethnic45 ethnic46 ethnic47 ethnic48 ethnic49 ethnic50 ethnic51 ethnic52 ethnic53 ethnic54 ethnic55 ethnic56 ethnic57 ethnic58 ethnic59 ethnic60 ethnic61 ethnic62 ethnic63 ethnic64 ethnic65 ethnic66 ethnic67 ethnic68 ethnic69 ethnic70 ethnic71 ethnic72 ethnic73 ethnic74 ethnic75 ethnic76 ethnic77 ethnic78 ethnic79 ethnic80 ethnic81 ethnic82 ethnic83 ethnic84 ethnic85 ethnic86 ethnic87 ethnic88 ethnic89 ethnic90 ethnic91 ethnic92 ethnic93 ethnic94 ethnic95 ethnic96 ethnic97 ethnic98 ethnic99 ethnic100 ethnic101 ethnic102 ethnic103 ethnic104 ethnic105 ethnic106 ethnic107 ethnic108 ethnic109 ethnic110 ethnic111 ethnic112 ethnic113 ethnic114 ethnic115 ethnic116 ethnic117)


*create aggregate ethnic groups based on https://www.iseas.edu.sg/images/pdf/iseas_working_papers_2014_1.pdf
do "${path}\1b_ethnic_indo.do"

gen ethnic_sh=ethnic1 if ethnicid_agg==1
forvalues i=2/18 {
	replace ethnic_sh=ethnic`i' if ethnicid_agg==`i'
}
forvalues i=19/58 {
	replace ethnic_sh=ethnic`i' if ethnicid_agg==`i'+1
}
forvalues i=59/117 {
	replace ethnic_sh=ethnic`i' if ethnicid_agg==`i'+2
}

drop ethnic1 ethnic2 ethnic3 ethnic4 ethnic5 ethnic6 ethnic7 ethnic8 ethnic9 ethnic10 ethnic11 ethnic12 ethnic13 ethnic14 ethnic15 ethnic16 ethnic17 ethnic18 ethnic19 ethnic20 ethnic21 ethnic22 ethnic23 ethnic24 ethnic25 ethnic26 ethnic27 ethnic28 ethnic29 ethnic30 ethnic31 ethnic32 ethnic33 ethnic34 ethnic35 ethnic36 ethnic37 ethnic38 ethnic39 ethnic40 ethnic41 ethnic42 ethnic43 ethnic44 ethnic45 ethnic46 ethnic47 ethnic48 ethnic49 ethnic50 ethnic51 ethnic52 ethnic53 ethnic54 ethnic55 ethnic56 ethnic57 ethnic58 ethnic59 ethnic60 ethnic61 ethnic62 ethnic63 ethnic64 ethnic65 ethnic66 ethnic67 ethnic68 ethnic69 ethnic70 ethnic71 ethnic72 ethnic73 ethnic74 ethnic75 ethnic76 ethnic77 ethnic78 ethnic79 ethnic80 ethnic81 ethnic82 ethnic83 ethnic84 ethnic85 ethnic86 ethnic87 ethnic88 ethnic89 ethnic90 ethnic91 ethnic92 ethnic93 ethnic94 ethnic95 ethnic96 ethnic97 ethnic98 ethnic99 ethnic100 ethnic101 ethnic102 ethnic103 ethnic104 ethnic105 ethnic106 ethnic107 ethnic108 ethnic109 ethnic110 ethnic111 ethnic112 ethnic113 ethnic114 ethnic115 ethnic116 ethnic117
save "${pathdata}\Indonesia_ethnic.dta", replace




