
use "${pathdata}\Malaysia.dta", clear


*recode educ
gen yrschool_i=. if edattaind>900|edattaind==0
replace yrschool_i=0 if edattaind==110
replace yrschool_i=3 if edattaind==120
replace yrschool_i=6 if edattaind==212
replace yrschool_i=9 if edattaind==221|edattaind==222
replace yrschool_i=12 if edattaind==311|edattaind==321
replace yrschool_i=15 if edattaind==400

replace yrschool=yrschool_i if yrschool==.

replace edattaind=. if edattaind>900|edattaind==0

*recode fertility
replace chborn=. if chborn>89
replace chsurv=chborn if chsurv>89			// chsurv is set to NIU while there's a value for CHBORN. I set the value of chsurv to that of chborn in those cases.
gen chborn_i= chborn
replace chborn_i= nchild if chborn==.&sex==2
gen chsurv_i= chsurv
replace chsurv_i= nchild if chsurv==.&sex==2
*create religion shares
tab religion, gen(rel1)					 // generating 7 dummies from religion variable 
recode religion (7 9 =1), g(rell)
tab rell, gen(rel2)					 // generating 5 dummies from religion variable 


save "${pathdata}\Malaysia_analysis.dta", replace

drop if age<18|age>55 						// All characteristics of regencies are computed using the adult working population
cap gen infmort=1-chsurv/chborn  			// Computes infant mortality based on the difference between chborn and chsurv
cap replace infmort=1-chsurv_i/chborn_i if infmort==.  			// Computes infant mortality based on the difference between chborn and chsurv

collapse (mean) rel11-rel17 rel21-rel25  yrschool infmort geolev1 [pweight=perwt], by(year geolev2) 

*rename district level variables
foreach var of varlist rel11-rel17 rel21-rel25 yrschool infmort {
rename `var' i`var'
}

save "${pathdata}\Malaysia_districts.dta", replace

clear*
use "${pathdata}\Malaysia_analysis.dta"
merge m:1 geolev2 year using "${pathdata}\Malaysia_districts.dta", keepusing(irel11-irel17 irel21-irel25 iyrschool iinfmort)
drop _m

*assign local share of own religious group to each observation 
cap drop rel_sh rel_shd
gen rel_shd=irel11 if religion==1
replace rel_shd=irel12 if religion==2
replace rel_shd=irel13 if religion==3
replace rel_shd=irel14 if religion==5
replace rel_shd=irel15 if religion==6
replace rel_shd=irel16 if religion==7
replace rel_shd=irel17 if religion==9

gen rel_sh=irel21 if rell==1
replace rel_sh=irel22 if rell==2
replace rel_sh=irel23 if rell==3
replace rel_sh=irel24 if rell==5
replace rel_sh=irel25 if rell==6

*create samples for regression analysis 
cap drop f_selec e_selec*
gen f_selec=1 if age>39&age<66&sex==2&yrschool!=.&iinfmort!=.&rel_sh!=.&edattaind!=.
gen e e_selec=3 if age>25&age<33&yrschool!=.&rel_sh!=.&edattaind!=.

gen birthyr=year-age
gen marr=(marst==2)
recode bplmy (15 = 12) (14 = 10)
gen mig=(458000+bplmy!=geolev1)

*Create indicators for the distribution of group size
cap drop rel_sh_*
xtile rel_sh_dec_f= rel_sh if f_selec==1, nq(10) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_e3= rel_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of rel_sh for education sample

xtile rel_sh_dec_20_f= rel_sh if f_selec==1, nq(20) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_20_e3= rel_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of rel_sh for education sample

* gen categories based on deciles, with first decile divided in 2 vintiles
gen rel_sh_dec_11_f=rel_sh_dec_20_f-1 if rel_sh_dec_20_f<3
replace rel_sh_dec_11_f=rel_sh_dec_f if rel_sh_dec_f>1
gen rel_sh_dec_11_e3=rel_sh_dec_20_e3-1 if rel_sh_dec_20_e3<3
replace rel_sh_dec_11_e3=rel_sh_dec_e3 if rel_sh_dec_e3>1 


cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values rel_sh_dec_11_f rel_shd_dec_11_f eleveniles
label values rel_sh_dec_11_e* rel_shd_dec_11_e* eleveniles


save "${pathdata}\Malaysia_analysis.dta", replace
