
use "${pathdata}\Senegal.dta", clear


*recode educ
gen yrschool=. if edattaind>900|edattaind==0
replace yrschool=0 if edattaind==110
replace yrschool=3 if edattaind==120
replace yrschool=6 if edattaind==212
replace yrschool=9 if edattaind==221|edattaind==222
replace yrschool=12 if edattaind==311|edattaind==321
replace yrschool=15 if edattaind==400


replace edattaind=. if edattaind>900|edattaind==0

*recode fertility
replace chborn=. if chborn>89
replace chsurv=chborn if chsurv>89			// chsurv is set to NIU while there's a value for CHBORN. I set the value of chsurv to that of chborn in those cases.

*create religion shares
recode religion (0=.)(7 9 =1)
tab religion, gen(rel)					 // generating 3 dummies from religion variable 


save "${pathdata}\Senegal_analysis.dta", replace

drop if age<18|age>55 						// All characteristics of regencies are computed using the adult working population
cap gen infmort=1-chsurv/chborn  			// Computes infant mortality based on the difference between chborn and chsurv
gen float wt=round(perwt*100)

collapse (mean) rel1 rel2 rel3  yrschool infmort geolev1 [fweight=wt], by(year geolev2) 

*rename district level variables
foreach var of varlist rel1-rel3 yrschool infmort {
rename `var' i`var'
}

save "${pathdata}\Senegal_districts.dta", replace  

clear*
use "${pathdata}\Senegal_analysis.dta"
merge m:1 geolev2 year using "$pathdata\Senegal_districts.dta", keepusing(irel1-irel3 iyrschool iinfmort)
drop _m

*assign local share of own religious group to each observation 
cap drop rel_sh rel_shd
gen rel_sh=irel1 if religion==1
replace rel_sh=irel2 if religion==5
replace rel_sh=irel3 if religion==6

*create samples for regression analysis (loosened the conditions wrt Indonesia to maximise sample size, 40-65 in fertility sample instead of 45-60 and)
cap drop f_selec e_selec*
gen f_selec=1 if age>39&age<66&sex==2&yrschool!=.&iinfmort!=.&rel_sh!=.&edattaind!=.
gen e_selec=3 if age>25&age<33&yrschool!=.&rel_sh!=.&edattaind!=.

gen birthyr=year-age
gen marr=(marst==2)

gen mig=(686010000+bplsn!=geolev2)


*Create indicators for the distribution of group size
cap drop rel_sh_*
xtile rel_sh_dec_f= rel_sh if f_selec==1, nq(10) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_e3= rel_sh if e_selec==3, nq(10) // create a categorical variable for the deciles of rel_sh for education sample

xtile rel_sh_dec_20= rel_sh, nq(20) // create a categorical variable for the deciles of rel_sh
xtile rel_sh_dec_20_f= rel_sh if f_selec==1, nq(20) // create a categorical variable for the deciles of rel_sh for fertility sample
xtile rel_sh_dec_20_e3= rel_sh if e_selec==3, nq(20) // create a categorical variable for the deciles of rel_sh for education sample

* gen categories based on deciles, with first decile divided in 2 vintiles
gen rel_sh_dec_11_f=rel_sh_dec_20_f-1 if rel_sh_dec_20_f<3
replace rel_sh_dec_11_f=rel_sh_dec_f if rel_sh_dec_f>1
gen rel_sh_dec_11_e=rel_sh_dec_20_e-1 if rel_sh_dec_20_e<3
replace rel_sh_dec_11_e3=rel_sh_dec_e if rel_sh_dec_e>1 


cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values rel_sh_dec_11_f rel_shd_dec_11_f eleveniles
label values rel_sh_dec_11_e* rel_shd_dec_11_e* eleveniles

save "${pathdata}\Senegal_analysis.dta", replace




