* descriptive stats

*******************************************************
* Table 1: Summary statistics at the individual level *
*******************************************************

use "$pathdata\Indonesia_analysis.dta", clear


label variable marr "Currently married (%)"
label variable urban "Urban status (%)"
label variable yrschool "Years of schooling"
label variable mig "Residing in province of birth (%)"
label variable age "Age"
label variable iyrschool "Average years of schooling in regency"
label variable iinfmort "Child mortality in regency (%)"

replace urban=urban-1

foreach var of varlist marr urban iinfmort mig {
	replace `var'=`var'*100
}
global controls1 "chborn chsurv marr age urban yrschool iyrschool iinfmort mig"
sutex  ${controls1} if f_selec==1, par lab digits(2) file("$path\output\Table1.tex") replace
global controls2 "yrschool age urban iyrschool mig"
sutex ${controls2} if e_selec==3, par lab digits(2) file("$path\output\Table1.tex")  append


********************************************************************
*Appendix - Table 1: Summary statistics on size of religious group *
********************************************************************

use "${pathdata}\regencies_religion.dta", clear

label variable irel4 "Muslim"
label variable irel5 "Catholic"
label variable irel6 "Protestant"
label variable irel7 "Confucianist"
label variable irel2 "Buddhist"
label variable irel3 "Hindu"
label variable iyrschool "Years of schooling"
label variable iinfmort "Child mortality"

drop irel1

forvalues i=2/7 {
replace irel`i'=irel`i'*100
}

program define xtsum2, eclass

syntax varlist

foreach var of local varlist {
    xtsum `var'

    tempname mat_`var'
    matrix mat_`var' = J(1, 7, .)
    matrix mat_`var'[1,1] = (`r(mean)', `r(sd)', `r(min)', `r(max)', `r(sd_b)', `r(sd_w)')
    matrix colnames mat_`var'= Mean "Std. Dev." Min Max "Bet. Std. Dev." "Wit. Std. Dev."
    matrix rownames mat_`var'= `var' 

    local matall `matall' mat_`var'
}

if `= wordcount("`varlist'")' > 1 {
    local matall = subinstr("`matall'", " ", " \ ",.)
    matrix allmat = (`matall')
    ereturn matrix mat_all = allmat
}
else ereturn matrix mat_all = mat_`varlist'

end


xtset geo2_id year
xtsum2 irel*
esttab e(mat_all) using "${path}\Output\App_Table1.tex", varlabels(r2 "Buddhist " r3 "Hindu " r4 "Muslim " r5 "Catholic " r6 "Protestant " r7 "Confucianist ") tex

**************************************************************
*Appendix - Figure 3: Distribution of regency-level controls *
**************************************************************

graph box iyrschool, over(year) graphregion(color(white)) 
graph export "${path}\Output\App_Figure3a.png", as(png) replace
graph box iinfmort, over(year) graphregion(color(white)) 
graph export "${path}\Output\App_Figure3b.png", as(png) replace


************************************************************************
* Appendix - Figure 5: Distribution of size of ethnic group by deciles *
************************************************************************

use "${pathdata}\indonesia_ethnic.dta"

keep if ethnic_sh!=.&f_selec==1
xtile ethnic_sh_dec_f= ethnic_sh, nq(10) 	// create a categorical variable for the deciles of ethnic_sh for fertility sample
xtile ethnic_sh_ven_f= ethnic_sh, nq(20)		// create a categorical variable for the ventiles of ethnic_sh
* gen categories based on deciles, with first decile divided in 2 ventiles
gen ethnic_sh_dec_11_f=ethnic_sh_ven_f-1 if ethnic_sh_ven_f<3
replace ethnic_sh_dec_11_f=ethnic_sh_dec_f if ethnic_sh_dec_f>1

cap label define eleveniles 0 "1st ventile" 1 "2nd ventile" 2 "2nd decile" 3 "3rd decile" 4 "4th decile" 5 "5th decile" 6 "6th decile" 7 "7th decile" 8 "8th decile" 9 "9th decile" 10 "10th decile"
label values ethnic_sh_dec_11_f eleveniles
label variable ethnic_sh_dec_11_f "Share of own ethnic group"
label variable ethnic_sh "Share of own ethnic group"
graph box ethnic_sh, over(ethnic_sh_dec_11_f, label(angle(45))) graphregion(color(white)) 
graph export "${path}\App_Figure5.png", as(png) replace

  

