*This file serves for the main analysis


***********************************************************
* Figure 6: Fertility and education choices by group size *
***********************************************************

*EDUCATION

use "${pathdata}\China_education.dta2", clear

matrix margin = J(3,11,.)
matrix colnames margin = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix CI = J(4,11,.)
matrix colnames CI = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix rownames CI = ll95 ul95 ll95 ul95

global exp_vard "ethn_sh_dec_11_e3"
global exp_var "ib9.ethn_sh_dec_11_e3"

reg ethn_sh $exp_var if e_selec ==3
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[3,`i'] = r(b)[1,`i']
}

gen urb=(urban==2)
global controls1 "i.birthyr i.urb##i.year"
global controls2 "c.iinfmort"
global controls3 "ib1.ethniccn i.sex"
global exp_vard "ethn_sh_dec_11_e3"
global exp_var "ib9.ethn_sh_dec_11_e3"
reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[1,`i'] = r(b)[1,`i']
matrix CI[1,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[2,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}
matrix b = margin'
svmat b, n(column)
label var column1 "years of schooling"
label var column2 "children ever born"
label var column3 "share of own religious group"

matrix c = CI'
svmat c, n(CI)
keep column1-column3 CI1-CI4
gen c4=.
forvalues i=1/11 {
replace c4=`i' in `i'
}
drop if c4==.
save "${pathdata}\China_sub.dta", replace

*FERTILITY

use "${pathdata}/China_fertility.dta", clear

clear matrix

matrix margin = J(3,11,.)
matrix colnames margin = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix CI = J(4,11,.)
matrix colnames CI = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix rownames CI = ll95 ul95 ll95 ul95

gen urb=(urban==2)
global controls1 "i.birthyr i.urb##i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattain i.marst ib1.ethniccn"
global exp_vard "ethn_sh_dec_11_f"
global exp_var "ib9.ethn_sh_dec_11_f"
poisson chborn $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[2,`i'] = r(b)[1,`i']
matrix CI[3,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[4,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}
cap drop column1-column3 c4 CI1-CI4
gen c4 = .

matrix b = margin'
svmat b, n(column)
label var column1 "years of schooling"
label var column2 "children ever born"
label var column3 "share of own religious group"

matrix c = CI'
svmat c, n(CI)

keep column1-column3 CI1-CI4
gen c4=.
forvalues i=1/11 {
replace c4=`i' in `i'
}
drop if c4==.

merge 1:m c4 using "${pathdata}\China_sub.dta", update
drop _merge

 cap ssc install grstyle

 
 tostring c4, replace
replace c4 = "1st ventile" in 1
 replace c4 = "2nd ventile" in 2
  replace c4 = "2nd decile" in 3
 replace c4 = "3rd decile" in 4
  replace c4 = "4th decile" in 5
   replace c4 = "5th decile" in 6
    replace c4 = "6th decile" in 7
	 replace c4 = "7th decile" in 8
	  replace c4 = "8th decile" in 9
	   replace c4 = "9th decile" in 10
	    replace c4 = "10th decile" in 11

grstyle clear
grstyle init
grstyle color background white
grstyle color major_grid black
grstyle linewidth major_grid vthin
grstyle linepattern major_grid dot
grstyle yesno grid_draw_min yes
grstyle yesno grid_draw_max yes

twoway (connected  column2 column1, mlabel(c4) mcolor(green) lcolor(green) ytitle("children ever born") mlabcolor(green) mlabposition(1) graphregion(fcolor(white)))
graph export "$path\Output\Figure6_china.png", as(png) replace

