*This file serves for the main analysis

use "${pathdata}/Indonesia_analysis.dta", clear


****************************************************
* Figure 5: Fertility and Education by Group Size *
****************************************************

global controls1 "i.birthyr i.urban##i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"


global exp_vard "rel_sh_dec_11_f"
global exp_var "ib9.rel_sh_dec_11_f"


foreach i in chborn chsurv {
eststo clear
eststo: poisson `i' $exp_var $controls1 if f_selec ==1, vce(cluster geolev2)
estimates store coef`i'1
margins i.$exp_vard, post
estimates store pred`i'1
eststo: poisson `i' $exp_var $controls1 $controls2  if f_selec ==1, vce(cluster geolev2)
estimates store coef`i'2
margins i.$exp_vard, post
estimates store pred`i'2
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geolev2)
estimates store coef`i'3
margins i.$exp_vard, post
estimates store pred`i'3
eststo: poisson `i' $exp_var $controls1 $controls2 $controls3  if f_selec ==1&mig==1, vce(cluster geolev2)
estimates store coef`i'4
margins i.$exp_vard, post
estimates store pred`i'4
coefplot (pred`i'1, label(model 1)) (pred`i'2, label(model 2)) (pred`i'3, label(model 3)) (pred`i'4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(rows(1))
graph export "${path}\Output\Figure5_`i'.png", as(png) replace
esttab coef* using "${path}\Output\Table_for_Figure5_`i'.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2_p, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" Pseudo-\(R^{2}\)"' ))
drop _est_coef*
drop _est_pred*
}

 
global controls1 "i.birthyr  i.urban##i.year"
global controls2 "c.iinfmort"
global controls3 "ib5000.religiond i.sex"


global exp_vard "rel_sh_dec_11_e3"
global exp_var "ib19.rel_sh_dec_11_e3"
eststo clear
eststo: reg yrschool $exp_var $controls1 if e_selec ==3, vce(cluster geolev2)
estimates store tool1
margins i.$exp_vard, post
estimates store pred1
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3, vce(cluster geolev2)
estimates store tool2
margins i.$exp_vard, post
estimates store pred2
eststo: reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geolev2)
estimates store tool3
margins i.$exp_vard, post
estimates store pred3
eststo: reg yrschool $exp_var $controls1 $controls2 if e_selec ==3&mig==1, vce(cluster geolev2)
estimates store tool4
margins i.$exp_vard, post
estimates store pred4
coefplot (pred1, label(model 1)) (pred2, label(model 2)) (pred3, label(model 3)) (pred4, label(model 4)), recast(scatter) vertical xlabel(, angle(45)) graphregion(color(white)) legend(rows(1))
graph export "$path\graphs\Output\Figure5_educ.png", as(png) replace
esttab coef* using "$path\output\Table_for_Figure5_educ.tex", replace ///
cells(" b(fmt(3)star) " "se(fmt(3)par)") drop(*.birthyr ) /// keep($keep )
	star(* 0.10 ** 0.05 *** 0.01) ///
	stats(N r2, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `" \(R^{2}\)"' ))
drop _est_tool*



***********************************************************
* Figure 6: Fertility and education choices by group size *
***********************************************************

matrix margin = J(3,11,.)
matrix colnames margin = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix CI = J(4,11,.)
matrix colnames CI = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix rownames CI = ll95 ul95 ll95 ul95

global exp_var "ib9.rel_sh_dec_11_e3"
global exp_vard "rel_sh_dec_11_e3"

reg rel_sh $exp_var if e_selec ==3
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[3,`i'] = r(b)[1,`i']
}

global controls1 "i.birthyr  i.urban##i.year"
global controls2 "c.iinfmort"
global controls3 "ib5000.religiond i.sex"
global exp_vard "rel_sh_dec_11_e3"
global exp_var "ib9.rel_sh_dec_11_e3"
reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[1,`i'] = r(b)[1,`i']
matrix CI[1,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[2,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}

global controls1 "i.birthyr i.urban##i.year"
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattaind i.marst ib5000.religiond"
global exp_vard "rel_sh_dec_11_f"								
global exp_var "ib9.rel_sh_dec_11_f"	
poisson chborn $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[2,`i'] = r(b)[1,`i']
matrix CI[3,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[4,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}
cap drop column1-column3 c4 CI1-CI4
gen c4 = .
tostring c4, replace
replace c4 = "1st ventile" in 1
 replace c4 = "2nd ventile" in 2
  replace c4 = "2nd decile" in 3
 replace c4 = "3rd decile" in 4
  replace c4 = "4th decile" in 5
   replace c4 = "5th decile" in 6
    replace c4 = "6th decile" in 7
	 replace c4 = "7th decile" in 8
	  replace c4 = "8th decile" in 9
	   replace c4 = "9th decile" in 10
	    replace c4 = "10th decile" in 11
matrix b = margin'
svmat b, n(column)
label var column1 "years of schooling"
label var column2 "children ever born"
label var column3 "share of own religious group"

matrix c = CI'
svmat c, n(CI)

twoway (connected  column2 column1, xscale(range(7.5(0.5)10.5)) mlabel(c4) mcolor(green) lcolor(green) ytitle("children ever born") mlabcolor(green) mlabposition(6) graphregion(fcolor(white)))
graph export "${path}\Output\Figure6_indonesia.png", as(png) replace

