********************************************************************
* Appendix Figure 4: Fertility and education choices by group size *
********************************************************************

use "${pathdata}\Mozambique_analysis.dta", clear


matrix margin = J(3,11,.)
matrix colnames margin = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix CI = J(4,11,.)
matrix colnames CI = "1st ventile" "2nd ventile" "2nd decile" "3rd decile" "4th decile" "5th decile" "6th decile" "7th decile" "8th decile" "9th decile" "10th decile"
matrix rownames CI = ll95 ul95 ll95 ul95

global exp_var "ib9.rel_sh_dec_11_e3"
global exp_vard "rel_sh_dec_11_e3"

reg rel_sh $exp_var if e_selec ==3
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[3,`i'] = r(b)[1,`i']
}


global controls1 "i.birthyr i.urban" 						// no year, because only 2007 (no religion data in 1997)
global controls2 "c.iinfmort"
global controls3 "ib1.religion i.sex"
global exp_vard "rel_sh_dec_11_e3"
global exp_var "ib9.rel_sh_dec_11_e3"
reg yrschool $exp_var $controls1 $controls2 $controls3 if e_selec ==3, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[1,`i'] = r(b)[1,`i']
matrix CI[1,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[2,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}

global controls1 "i.birthyr i.urban"						// no year, because only 2007 (no religion data in 1997)
global controls2 "c.iinfmort c.iyrschool"
global controls3 "i.edattain i.marst ib1.religion"
global exp_vard "rel_sh_dec_11_f"								
global exp_var "ib9.rel_sh_dec_11_f"	
poisson chborn $exp_var $controls1 $controls2 $controls3 if f_selec ==1, vce(cluster geolev2)
margins i.$exp_vard, post
forvalues i=1/11 {
matrix margin[2,`i'] = r(b)[1,`i']
matrix CI[3,`i'] = r(b)[1,`i']-sqrt(r(V)[`i',`i'])*1.96
matrix CI[4,`i'] = r(b)[1,`i']+sqrt(r(V)[`i',`i'])*1.96
}
cap drop column1-column3 c4 CI1-CI4
gen c4 = .
tostring c4, replace
replace c4 = "1st ventile" in 1
 replace c4 = "2nd ventile" in 2
  replace c4 = "2nd decile" in 3
 replace c4 = "3rd decile" in 4
  replace c4 = "4th decile" in 5
   replace c4 = "5th decile" in 6
    replace c4 = "6th decile" in 7
	 replace c4 = "7th decile" in 8
	  replace c4 = "8th decile" in 9
	   replace c4 = "9th decile" in 10
	    replace c4 = "10th decile" in 11
matrix b = margin'
svmat b, n(column)
label var column1 "years of schooling"
label var column2 "children ever born"
label var column3 "share of own religious group"

matrix c = CI'
svmat c, n(CI)
 cap ssc install grstyle


grstyle clear
grstyle init
grstyle color background white
grstyle color major_grid black
grstyle linewidth major_grid vthin
grstyle linepattern major_grid dot
grstyle yesno grid_draw_min yes
grstyle yesno grid_draw_max yes

twoway (connected  column2 column1, xscale(range(2.2(0.2)3.2)) mlabel(c4) mcolor(green) lcolor(green) ytitle("children ever born") mlabcolor(green) mlabposition(1) graphregion(fcolor(white)))
graph export "${path}\Output\App_Figure4_mozabique.png", as(png) replace
